import pytz
from django import template
from ..utils import get_long_date, get_long_datetime

DAYS_OF_WEEK = ['Lu', 'Ma', 'Me', 'Je', 'Ve', 'Sa', 'Di']

register = template.Library()

tz = pytz.timezone("Europe/Brussels")


@register.filter
def weekday(value):
    return DAYS_OF_WEEK[value.weekday()]


@register.filter
def long_date(value):
    return get_long_date(value)


@register.filter
def long_datetime(value):
    return get_long_datetime(value)


@register.filter
def short_datetime(value):
    return value.astimezone(tz).strftime('%d/%m/%Y %H:%M')



import openpyxl

import xlrd


class SheetReader:
    def range(self): return None
    def cell(self, row, column): return None
    def header(self, column): return None


class SheetReaderXls(SheetReader):
    def __init__(self, full_path):
        workbook = xlrd.open_workbook(full_path)
        self.sheet = workbook.sheet_by_index(0)

    def range(self): return range(0, self.sheet.nrows)
    def cell(self, row, column): return self.sheet.cell(row, column)
    def header(self, column): return self.sheet.cell(0, column)


class SheetReaderXlsx(SheetReader):
    def __init__(self, full_path):
        wb_obj = openpyxl.load_workbook(full_path)
        self.sheet = wb_obj.active

    def range(self): return self.sheet.iter_rows(max_row=self.sheet.max_row)
    def cell(self, row, column): return row[column]
    def header(self, column): return self.sheet.cell(1, column + 1)


def create_reader(path):
    extension = '.xlsx' if path.endswith('.xlsx') else '.xls'
    return SheetReaderXls(path) if extension == '.xls' else SheetReaderXlsx(path)



# -*- coding: utf-8 -*-

from django.conf import settings
from django.contrib.auth import authenticate, login, logout
from django.contrib.auth.models import User
from django.http import HttpResponseRedirect
from django.shortcuts import render
from django.urls import reverse


def user_login(request):
    error = None
    if 'username' in request.POST and 'password' in request.POST:
        username = request.POST['username']
        password = request.POST['password']
        user = authenticate(request, username=username, password=password)
        if user is not None:
            login(request, user)
            return HttpResponseRedirect(reverse(settings.DEFAULT_SPACE + ':home'))
        if len(User.objects.filter(username=username)) < 1:
            error = "Ce nom d'utilisateur est inconnu"
        else:
            error = "Le mot de passe est incorrect"
    context = {'error': error}
    return render(request, 'user_login.html', context)


def user_logout(request):
    logout(request)
    return render(request, 'user_logout.html')




# Generated by Django 2.2 on 2023-05-07 13:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django', '0011_auto_20230211_1150'),
    ]

    operations = [
        #migrations.RemoveField(
        #    model_name='formtemplateitem',
        #    name='form_template',
        #),
        #migrations.DeleteModel(
        #    name='FormTemplate',
        #),
        #migrations.DeleteModel(
        #    name='FormTemplateItem',
        #),
    ]
